@@ -1,4 +1,4 @@
-/* Copyright 2007 Matthew Barnes
+/* Copyright 2007, 2008 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -16,25 +16,32 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+/**
+ * SECTION: gva-time
+ * @short_description: A #GBoxed type for time_t
+ *
+ * A portable #GType for <type>time_t</type>.
+ *
+ * IEEE 1003.1 does not specify the size of <type>time_t</type>, nor even
+ * whether it's an integer or floating-point type, so we have to represent
+ * the value as a subtype of #G_TYPE_BOXED.
+ **/
+
 #ifndef GVA_TIME_H
 #define GVA_TIME_H
 
 #include "gva-common.h"
 
-/* Create a portable GType for time_t.
+/**
+ * GVA_TYPE_TIME:
  *
- * IEEE 1003.1 does not specify the size of time_t, nor even whether it's
- * an integer or floating-point type.  So represent the value as a subtype
- * of G_TYPE_BOXED.
- */
-
+ * The #GType for a boxed type holding a <type>time_t</type> value.
+ **/
 #define GVA_TYPE_TIME   (gva_time_get_type ())
 
 G_BEGIN_DECLS
 
 GType           gva_time_get_type               (void);
-void            gva_time_set_tree_sortable_func (GtkTreeSortable *sortable,
-                                                 gint sort_column_id);
 
 G_END_DECLS
 
