@@ -42,6 +42,7 @@
 #define GVA_ACTION_PROPERTIES           (gva_ui_get_action ("properties"))
 #define GVA_ACTION_QUIT                 (gva_ui_get_action ("quit"))
 #define GVA_ACTION_RECORD               (gva_ui_get_action ("record"))
+#define GVA_ACTION_REMOVE_COLUMN        (gva_ui_get_action ("remove-column"))
 #define GVA_ACTION_REMOVE_FAVORITE      (gva_ui_get_action ("remove-favorite"))
 #define GVA_ACTION_SAVE_ERRORS          (gva_ui_get_action ("save-errors"))
 #define GVA_ACTION_SEARCH               (gva_ui_get_action ("search"))
@@ -65,6 +66,10 @@
         (gva_ui_get_widget ("main-progress-bar"))
 #define GVA_WIDGET_MAIN_PROPERTIES_BUTTON \
         (gva_ui_get_widget ("main-properties-button"))
+#define GVA_WIDGET_MAIN_SEARCH_ENTRY \
+        (gva_ui_get_widget ("main-search-entry"))
+#define GVA_WIDGET_MAIN_SEARCH_HBOX \
+        (gva_ui_get_widget ("main-search-hbox"))
 #define GVA_WIDGET_MAIN_START_GAME_BUTTON \
         (gva_ui_get_widget ("main-start-game-button"))
 #define GVA_WIDGET_MAIN_STATUSBAR \
@@ -109,32 +114,55 @@
 /* Properties Window */
 #define GVA_WIDGET_PROPERTIES_BACK_BUTTON \
         (gva_ui_get_widget ("properties-back-button"))
+#define GVA_WIDGET_PROPERTIES_BIOS_LABEL \
+        (gva_ui_get_widget ("properties-bios-label"))
+#define GVA_WIDGET_PROPERTIES_BIOS_VBOX \
+        (gva_ui_get_widget ("properties-bios-vbox"))
 #define GVA_WIDGET_PROPERTIES_CLOSE_BUTTON \
         (gva_ui_get_widget ("properties-close-button"))
+#define GVA_WIDGET_PROPERTIES_CPU_VBOX \
+        (gva_ui_get_widget ("properties-cpu-vbox"))
 #define GVA_WIDGET_PROPERTIES_FORWARD_BUTTON \
         (gva_ui_get_widget ("properties-forward-button"))
 #define GVA_WIDGET_PROPERTIES_HEADER \
         (gva_ui_get_widget ("properties-header"))
 #define GVA_WIDGET_PROPERTIES_HISTORY_TEXT_VIEW \
         (gva_ui_get_widget ("properties-history-text-view"))
+#define GVA_WIDGET_PROPERTIES_IMPERFECT_COLOR_LABEL \
+        (gva_ui_get_widget ("properties-imperfect-color-label"))
+#define GVA_WIDGET_PROPERTIES_IMPERFECT_GRAPHIC_LABEL \
+        (gva_ui_get_widget ("properties-imperfect-graphic-label"))
+#define GVA_WIDGET_PROPERTIES_IMPERFECT_SOUND_LABEL \
+        (gva_ui_get_widget ("properties-imperfect-sound-label"))
 #define GVA_WIDGET_PROPERTIES_NOTEBOOK \
         (gva_ui_get_widget ("properties-notebook"))
+#define GVA_WIDGET_PROPERTIES_PRELIMINARY_COCKTAIL_LABEL \
+        (gva_ui_get_widget ("properties-preliminary-cocktail-label"))
+#define GVA_WIDGET_PROPERTIES_PRELIMINARY_COLOR_LABEL \
+        (gva_ui_get_widget ("properties-preliminary-color-label"))
+#define GVA_WIDGET_PROPERTIES_PRELIMINARY_EMULATION_LABEL \
+        (gva_ui_get_widget ("properties-preliminary-emulation-label"))
+#define GVA_WIDGET_PROPERTIES_PRELIMINARY_PROTECTION_LABEL \
+        (gva_ui_get_widget ("properties-preliminary-protection-label"))
+#define GVA_WIDGET_PROPERTIES_PRELIMINARY_SOUND_LABEL \
+        (gva_ui_get_widget ("properties-preliminary-sound-label"))
+#define GVA_WIDGET_PROPERTIES_SOUND_VBOX \
+        (gva_ui_get_widget ("properties-sound-vbox"))
+#define GVA_WIDGET_PROPERTIES_STATUS_HBOX \
+        (gva_ui_get_widget ("properties-status-hbox"))
+#define GVA_WIDGET_PROPERTIES_STATUS_IMAGE \
+        (gva_ui_get_widget ("properties-status-image"))
+#define GVA_WIDGET_PROPERTIES_VIDEO_VBOX \
+        (gva_ui_get_widget ("properties-video-vbox"))
 #define GVA_WIDGET_PROPERTIES_WINDOW \
         (gva_ui_get_widget ("properties-window"))
 
-/* Search Window */
-#define GVA_WIDGET_SEARCH_ENTRY \
-        (gva_ui_get_widget ("search-entry"))
-#define GVA_WIDGET_SEARCH_FIND_BUTTON \
-        (gva_ui_get_widget ("search-find-button"))
-#define GVA_WIDGET_SEARCH_WINDOW \
-        (gva_ui_get_widget ("search-window"))
-
 G_BEGIN_DECLS
 
 GtkAction *     gva_ui_get_action               (const gchar *action_name);
 GtkWidget *     gva_ui_get_widget               (const gchar *widget_name);
 GtkWidget *     gva_ui_get_managed_widget       (const gchar *widget_path);
+void            gva_ui_add_column_actions       (GtkTreeView *view);
 
 G_END_DECLS
 
